@@ -28,29 +28,6 @@ if (! empty($_REQUEST['target'])) {
  */
 require './libraries/plugins/auth/swekey/swekey.auth.lib.php';
 
-/**
- * Initialization
- * Store the initialization vector because it will be needed for
- * further decryption. I don't think necessary to have one iv
- * per server so I don't put the server number in the cookie name.
- */
-if (function_exists('mcrypt_encrypt')) {
-    if (empty($_COOKIE['pma_mcrypt_iv'])
-        || ! ($iv = base64_decode($_COOKIE['pma_mcrypt_iv'], true))
-    ) {
-        srand((double) microtime() * 1000000);
-        $td = mcrypt_module_open(MCRYPT_BLOWFISH, '', MCRYPT_MODE_CBC, '');
-        if ($td === false) {
-            PMA_fatalError(__('Failed to use Blowfish from mcrypt!'));
-        }
-        $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
-        $GLOBALS['PMA_Config']->setCookie(
-            'pma_mcrypt_iv',
-            base64_encode($iv)
-        );
-    }
-}
-
 /**
  * Handles the cookie authentication method
  *
@@ -58,14 +35,19 @@ if (function_exists('mcrypt_encrypt')) {
  */
 class AuthenticationCookie extends AuthenticationPlugin
 {
+    /**
+     * IV for Blowfish.
+     */
+    private $_blowfish_iv = null;
+
     /**
      * Displays authentication form
      *
      * this function MUST exit/quit the application
      *
-     * @global string the last connection error
+     * @global string $conn_error the last connection error
      *
-     * @return void
+     * @return boolean|void
      */
     public function auth()
     {
@@ -75,34 +57,15 @@ class AuthenticationCookie extends AuthenticationPlugin
         if ($response->isAjax()) {
             $response->isSuccess(false);
 
-            $login_link = '<br /><br />[ ' .
-                sprintf(
-                    '<a href="%s" class="ajax login-link">%s</a>', 
-                    $GLOBALS['cfg']['PmaAbsoluteUri'], 
-                    __('Log in')
-                )
-                . ' ]';
-
-            if (! empty($conn_error)) {
-
-                $conn_error .= $login_link;
-
-                $response->addJSON(
-                    'message',
-                    PMA_Message::error(
-                        $conn_error
-                    )
-                );
+            $response->addJSON(
+                'redirect_flag',
+                '1'
+            );
+            if (defined('TESTSUITE')) {
+                return true;
             } else {
-                $response->addJSON(
-                    'message',
-                    PMA_Message::error(
-                        __('Your session has expired. Please log in again.') .
-                        $login_link
-                    )
-                );
+                exit;
             }
-            exit;
         }
 
         /* Perform logout to custom URL */
@@ -110,7 +73,11 @@ class AuthenticationCookie extends AuthenticationPlugin
             && ! empty($GLOBALS['cfg']['Server']['LogoutURL'])
         ) {
             PMA_sendHeaderLocation($GLOBALS['cfg']['Server']['LogoutURL']);
-            exit;
+            if (defined('TESTSUITE')) {
+                return true;
+            } else {
+                exit;
+            }
         }
 
         // No recall if blowfish secret is not configured as it would produce
@@ -128,8 +95,6 @@ class AuthenticationCookie extends AuthenticationPlugin
             $autocomplete   = ' autocomplete="off"';
         }
 
-        $cell_align = ($GLOBALS['text_dir'] == 'ltr') ? 'left' : 'right';
-
         $response->getFooter()->setMinimal();
         $header = $response->getHeader();
         $header->setBodyId('loginform');
@@ -165,11 +130,17 @@ class AuthenticationCookie extends AuthenticationPlugin
         // Show error message
         if (! empty($conn_error)) {
             PMA_Message::rawError($conn_error)->display();
+        } elseif (isset($_GET['session_expired'])
+            && intval($_GET['session_expired']) == 1
+        ) {
+            PMA_Message::rawError(
+                __('Your session has expired. Please log in again.')
+            )->display();
         }
 
         echo "<noscript>\n";
         PMA_message::error(
-            __("Javascript must be enabled past this point")
+            __("Javascript must be enabled past this point!")
         )->display();
         echo "</noscript>\n";
 
@@ -222,7 +193,7 @@ class AuthenticationCookie extends AuthenticationPlugin
             </div>';
         if (count($GLOBALS['cfg']['Servers']) > 1) {
             echo '<div class="item">
-                <label for="select_server">' . __('Server Choice') .':</label>
+                <label for="select_server">' . __('Server Choice:') . '</label>
                 <select name="server" id="select_server"';
             if ($GLOBALS['cfg']['AllowArbitraryServer']) {
                 echo ' onchange="document.forms[\'login_form\'].'
@@ -239,6 +210,52 @@ class AuthenticationCookie extends AuthenticationPlugin
                 . $GLOBALS['server'] . '" />';
         } // end if (server choice)
 
+        // We already have one correct captcha.
+        $skip = false;
+        if (  isset($_SESSION['last_valid_captcha'])
+            && $_SESSION['last_valid_captcha']
+        ) {
+            $skip = true;
+        }
+
+        // Add captcha input field if reCaptcha is enabled
+        if (  !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
+            && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
+            && !$skip
+        ) {
+            // If enabled show captcha to the user on the login screen.
+            echo '<script type="text/javascript">
+                    var RecaptchaOptions = {
+                        theme : "white"
+                    };
+                 </script>
+                 <script type="text/javascript"
+                    src="https://www.google.com/recaptcha/api/challenge?'
+                    . 'k=' . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '&amp;'
+                    . 'hl=' . $GLOBALS['lang'] . '">
+                 </script>
+                 <noscript>
+                    <iframe src="https://www.google.com/recaptcha/api/noscript?k='
+                . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '"
+                        height="300" width="500" frameborder="0"></iframe><br>
+                    <textarea name="recaptcha_challenge_field" rows="3" cols="40">
+                    </textarea>
+                    <input type="hidden" name="recaptcha_response_field"
+                        value="manual_challenge">
+                 </noscript>
+                 <script type="text/javascript">
+                    $(function() {
+                        $("#recaptcha_reload_btn").addClass("disableAjax");
+                        $("#recaptcha_switch_audio_btn").addClass("disableAjax");
+                        $("#recaptcha_switch_img_btn").addClass("disableAjax");
+                        $("#recaptcha_whatsthis_btn").addClass("disableAjax");
+                        $("#recaptcha_audio_play_again").live("mouseover", function() {
+                            $(this).addClass("disableAjax");
+                        });
+                    });
+                 </script>';
+        }
+
         echo '</fieldset>
         <fieldset class="tblFooters">
             <input value="' . __('Go') . '" type="submit" id="input_go" />';
@@ -254,7 +271,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         }
         // do not generate a "server" hidden field as we want the "server"
         // drop-down to have priority
-        echo PMA_generate_common_hidden_inputs($_form_params, '', 0, 'server');
+        echo PMA_URL_getHiddenInputs($_form_params, '', 0, 'server');
         echo '</fieldset>
     </form>';
 
@@ -271,7 +288,11 @@ class AuthenticationCookie extends AuthenticationPlugin
         if (file_exists(CUSTOM_FOOTER_FILE)) {
             include CUSTOM_FOOTER_FILE;
         }
-        exit;
+        if (! defined('TESTSUITE')) {
+            exit;
+        } else {
+            return true;
+        }
     }
 
     /**
@@ -279,7 +300,7 @@ class AuthenticationCookie extends AuthenticationPlugin
      *
      * this function DOES NOT check authentication - it just checks/provides
      * authentication credentials required to connect to the MySQL server
-     * usually with PMA_DBI_connect()
+     * usually with $GLOBALS['dbi']->connect()
      *
      * it returns false if something is missing - which usually leads to
      * auth() which displays login form
@@ -296,6 +317,8 @@ class AuthenticationCookie extends AuthenticationPlugin
      */
     public function authCheck()
     {
+        global $conn_error;
+
         // Initialization
         /**
          * @global $GLOBALS['pma_auth_server'] the user provided server to
@@ -307,7 +330,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         $GLOBALS['from_cookie'] = false;
 
         // BEGIN Swekey Integration
-        if (! Swekey_auth_check()) {
+        if (! Swekey_Auth_check()) {
             return false;
         }
         // END Swekey Integration
@@ -321,6 +344,54 @@ class AuthenticationCookie extends AuthenticationPlugin
             return false;
         }
 
+        // We already have one correct captcha.
+        $skip = false;
+        if (  isset($_SESSION['last_valid_captcha'])
+            && $_SESSION['last_valid_captcha']
+        ) {
+            $skip = true;
+        }
+
+        // Verify Captcha if it is required.
+        if (  !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
+            && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
+            && !$skip
+        ) {
+            if (  !empty($_POST["recaptcha_challenge_field"])
+                && !empty($_POST["recaptcha_response_field"])
+            ) {
+                include_once 'libraries/plugins/auth/recaptchalib.php';
+
+                // Use private key to verify captcha status.
+                $resp = recaptcha_check_answer(
+                    $GLOBALS['cfg']['CaptchaLoginPrivateKey'],
+                    $_SERVER["REMOTE_ADDR"],
+                    $_POST["recaptcha_challenge_field"],
+                    $_POST["recaptcha_response_field"]
+                );
+
+                // Check if the captcha entered is valid, if not stop the login.
+                if ( !$resp->is_valid ) {
+                    $conn_error = __('Entered captcha is wrong, try again!');
+                    $_SESSION['last_valid_captcha'] = false;
+                    return false;
+                } else {
+                    $_SESSION['last_valid_captcha'] = true;
+                }
+            } elseif (! empty($_POST["recaptcha_challenge_field"])
+                && empty($_POST["recaptcha_response_field"])
+            ) {
+                $conn_error = __('Please enter correct captcha!');
+                return false;
+            } else {
+                if (! isset($_SESSION['last_valid_captcha'])
+                    || ! $_SESSION['last_valid_captcha']
+                ) {
+                    return false;
+                }
+            }
+        }
+
         if (! empty($_REQUEST['old_usr'])) {
             // The user wants to be logged out
             // -> delete his choices that were stored in session
@@ -328,7 +399,11 @@ class AuthenticationCookie extends AuthenticationPlugin
             // according to the PHP manual we should do this before the destroy:
             //$_SESSION = array();
 
-            session_destroy();
+            if (! defined('TESTSUITE')) {
+                session_destroy();
+                // $_SESSION array is not immediately emptied
+                $_SESSION['last_valid_captcha'] = false;
+            }
             // -> delete password cookie(s)
             if ($GLOBALS['cfg']['LoginCookieDeleteAll']) {
                 foreach ($GLOBALS['cfg']['Servers'] as $key => $val) {
@@ -372,8 +447,10 @@ class AuthenticationCookie extends AuthenticationPlugin
                 = $_COOKIE['pmaServer-' . $GLOBALS['server']];
         }
 
-        // username
-        if (empty($_COOKIE['pmaUser-' . $GLOBALS['server']])) {
+        // check cookies
+        if (empty($_COOKIE['pmaUser-' . $GLOBALS['server']])
+            || empty($_COOKIE['pma_mcrypt_iv'])
+        ) {
             return false;
         }
 
@@ -391,17 +468,21 @@ class AuthenticationCookie extends AuthenticationPlugin
         $last_access_time = time() - $GLOBALS['cfg']['LoginCookieValidity'];
         if ($_SESSION['last_access_time'] < $last_access_time
         ) {
-            PMA_Util::cacheUnset('is_create_db_priv', true);
-            PMA_Util::cacheUnset('is_process_priv', true);
-            PMA_Util::cacheUnset('is_reload_priv', true);
-            PMA_Util::cacheUnset('db_to_create', true);
-            PMA_Util::cacheUnset('dbs_where_create_table_allowed', true);
+            PMA_Util::cacheUnset('is_create_db_priv', null);
+            PMA_Util::cacheUnset('is_process_priv', null);
+            PMA_Util::cacheUnset('is_reload_priv', null);
+            PMA_Util::cacheUnset('db_to_create', null);
+            PMA_Util::cacheUnset('dbs_where_create_table_allowed', null);
             $GLOBALS['no_activity'] = true;
             $this->authFails();
-            exit;
+            if (! defined('TESTSUITE')) {
+                exit;
+            } else {
+                return false;
+            }
         }
 
-        // password
+        // check password cookie
         if (empty($_COOKIE['pmaPass-' . $GLOBALS['server']])) {
             return false;
         }
@@ -475,16 +556,8 @@ class AuthenticationCookie extends AuthenticationPlugin
         unset($_SERVER['PHP_AUTH_PW']);
 
         $_SESSION['last_access_time'] = time();
-    }
 
-    /**
-     * Stores user credentials after successful login.
-     *
-     * @return void
-     */
-    public function storeUserCredentials()
-    {
-        global $cfg;
+        $this->createBlowfishIV();
 
         // Name and password cookies need to be refreshed each time
         // Duration = one month for username
@@ -552,10 +625,14 @@ class AuthenticationCookie extends AuthenticationPlugin
             PMA_Response::getInstance()->disable();
 
             PMA_sendHeaderLocation(
-                $redirect_url . PMA_generate_common_url($url_params, '&'),
+                $redirect_url . PMA_URL_getCommon($url_params, '&'),
                 true
             );
-            exit;
+            if (! defined('TESTSUITE')) {
+                exit;
+            } else {
+                return false;
+            }
         } // end if
 
         return true;
@@ -586,13 +663,13 @@ class AuthenticationCookie extends AuthenticationPlugin
                 . ' (see AllowNoPassword)'
             );
         } elseif (! empty($GLOBALS['allowDeny_forbidden'])) {
-            $conn_error = __('Access denied');
+            $conn_error = __('Access denied!');
         } elseif (! empty($GLOBALS['no_activity'])) {
             $conn_error = sprintf(
-                __('No activity within %s seconds; please log in again'),
+                __('No activity within %s seconds; please log in again.'),
                 $GLOBALS['cfg']['LoginCookieValidity']
             );
-        } elseif (PMA_DBI_getError()) {
+        } elseif ($GLOBALS['dbi']->getError()) {
             $conn_error = '#' . $GLOBALS['errno'] . ' '
                 . __('Cannot log in to the MySQL server');
         } else {
@@ -636,7 +713,6 @@ class AuthenticationCookie extends AuthenticationPlugin
      */
     public function blowfishEncrypt($data, $secret)
     {
-        global $iv;
         if (! function_exists('mcrypt_encrypt')) {
             /**
              * This library uses mcrypt when available, so
@@ -644,7 +720,7 @@ class AuthenticationCookie extends AuthenticationPlugin
              * if/then/else logic, however the include_once
              * call is costly
              */
-            include_once "./libraries/phpseclib/Crypt/AES.php";
+            include_once PHPSECLIB_INC_DIR . '/Crypt/AES.php';
             $cipher = new Crypt_AES(CRYPT_AES_MODE_ECB);
             $cipher->setKey($secret);
             return base64_encode($cipher->encrypt($data));
@@ -655,7 +731,7 @@ class AuthenticationCookie extends AuthenticationPlugin
                     $secret,
                     $data,
                     MCRYPT_MODE_CBC,
-                    $iv
+                    $this->_blowfish_iv
                 )
             );
         }
@@ -672,9 +748,11 @@ class AuthenticationCookie extends AuthenticationPlugin
      */
     public function blowfishDecrypt($encdata, $secret)
     {
-        global $iv;
+        if (is_null($this->_blowfish_iv)) {
+            $this->_blowfish_iv = base64_decode($_COOKIE['pma_mcrypt_iv'], true);
+        }
         if (! function_exists('mcrypt_encrypt')) {
-            include_once "./libraries/phpseclib/Crypt/AES.php";
+            include_once PHPSECLIB_INC_DIR . '/Crypt/AES.php';
             $cipher = new Crypt_AES(CRYPT_AES_MODE_ECB);
             $cipher->setKey($secret);
             return $cipher->decrypt(base64_decode($encdata));
@@ -685,12 +763,56 @@ class AuthenticationCookie extends AuthenticationPlugin
                 $secret,
                 $data,
                 MCRYPT_MODE_CBC,
-                $iv
+                $this->_blowfish_iv
             );
             return trim($decrypted);
         }
     }
 
+    /**
+     * Initialization
+     * Store the initialization vector because it will be needed for
+     * further decryption. I don't think necessary to have one iv
+     * per server so I don't put the server number in the cookie name.
+     *
+     * @return void
+     */
+    public function createBlowfishIV()
+    {
+        if (function_exists('mcrypt_encrypt')) {
+            $td = mcrypt_module_open(MCRYPT_BLOWFISH, '', MCRYPT_MODE_CBC, '');
+            if ($td === false) {
+                PMA_fatalError(__('Failed to use Blowfish from mcrypt!'));
+            }
+            $this->_blowfish_iv = mcrypt_create_iv(
+                mcrypt_enc_get_iv_size($td),
+                MCRYPT_DEV_URANDOM
+            );
+        } else {
+            /*
+             * We don't use this value without mcrypt, but let's set it
+             * so that we don't have to check conditionally for it.
+             */
+            $this->_blowfish_iv = 'dummy';
+        }
+        $GLOBALS['PMA_Config']->setCookie(
+            'pma_mcrypt_iv',
+            base64_encode($this->_blowfish_iv)
+        );
+    }
+
+    /**
+     * Sets Blowfis IV to use
+     *
+     * @param string $vector The IV
+     *
+     * @return void
+     */
+    public function setBlowfishIv($vector)
+    {
+        $this->_blowfish_iv = $vector;
+    }
+
     /**
      * This method is called when any PluginManager to which the observer
      * is attached calls PluginManager::notify()
